@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from __future__ import annotations
 import logging
 from typing import Union, Tuple, List, Dict, Any, Callable, Set, Optional
@@ -157,8 +156,12 @@ class Query(object):
 			logging.exception(e)
 			self.queries = None
 			return self
+		startCursor = endCursor = None
 		if "cursor" in filters and filters["cursor"] and filters["cursor"].lower() != "none":
-			self.setCursor(filters["cursor"])
+			startCursor = filters["cursor"]
+		if "endcursor" in filters and filters["endcursor"] and filters["endcursor"].lower() != "none":
+			endCursor = filters["endcursor"]
+		self.setCursor(startCursor, endCursor)
 		if "limit" in filters and str(filters["limit"]).isdigit() and int(filters["limit"]) > 0 and int(
 				filters["limit"]) <= 100:
 			self.limit(int(filters["limit"]))
@@ -493,7 +496,7 @@ class Query(object):
 			return list(Get([x.key.parent for x in resultList]))
 		return resultList
 
-	def run(self, limit=-1, **kwargs) -> List[Entity]:
+	def run(self, limit: int = -1) -> List[Entity]:
 		"""
 			Run this query.
 
@@ -503,9 +506,6 @@ class Query(object):
 			should be used.
 
 			:param limit: Limits the query to the defined maximum entities.
-			:type limit: int
-
-			:param kwargs: Any keyword arguments accepted by datastore_query.QueryOptions().
 
 			:returns: The list of found entities
 
@@ -553,7 +553,7 @@ class Query(object):
 			self._lastEntry = res[-1]
 		return res
 
-	def fetch(self, limit: int=-1, **kwargs) -> List['SkeletonInstanceRef']:
+	def fetch(self, limit: int = -1) -> List['SkeletonInstanceRef']:
 		"""
 			Run this query and fetch results as :class:`server.skeleton.SkelList`.
 
@@ -577,7 +577,7 @@ class Query(object):
 		if self.srcSkel is None:
 			raise NotImplementedError("This query has not been created using skel.all()")
 		# limit = limit if limit != -1 else self._limit
-		if limit != -1 and not (0 < limit < 100):
+		if limit != -1 and not (0 < limit <= 100):
 			logging.error(("Limit", limit))
 			raise NotImplementedError(
 				"This query is not limited! You must specify an upper bound using limit() between 1 and 100")
@@ -605,9 +605,6 @@ class Query(object):
 			:warning: If iterating over a large result set, make sure the query supports cursors. \
 			Otherwise, it might not return all results as the AppEngine doesn't maintain the view \
 			for a query for more than ~30 seconds.
-
-			:param keysOnly: If the query should be used to retrieve entity keys only.
-			:type keysOnly: bool
 		"""
 		if self.queries is None:  # Noting to pull here
 			raise StopIteration()
@@ -650,16 +647,11 @@ class Query(object):
 		self.srcSkel.setEntity(res)
 		return self.srcSkel
 
-	def clone(self, keysOnly=None) -> 'Query':
+	def clone(self) -> 'Query':
 		"""
 			Returns a deep copy of the current query.
 
-			:param keysOnly: If the query should be used to retrieve entity keys only\
-			in the new query.
-			:type keysOnly: bool
-
 			:returns: The cloned query.
-			:rtype: server.db.Query
 		"""
 		res = Query(self.getKind(), self.srcSkel)
 		res.kind = self.kind
